import React from 'react';
import { ActivityIndicator, StyleSheet, View } from 'react-native';
import { DefaultTheme } from '../utils';
/**
 * Displays a loading indicator within a window,
 *
 * @component
 * @example
 * <LoadingWindow
 *   styles={customStyles}
 *   mode="light"
 *   theme={customThemeProps}
 * />
 *
 * @param {Object} props - The properties passed to the component.
 * @param {Object} props.styles - Custom styles applied to the loading window container.
 * @param {ThemeMode} props.mode - The theme mode: 'light' or 'dark' mode
 * @param {ThemeProps} [props.theme] - Optional theme properties to customize the appearance.
 */
const LoadingWindow = props => {
  const {
    mode,
    theme
  } = props;
  return /*#__PURE__*/React.createElement(View, {
    style: style.container
  }, /*#__PURE__*/React.createElement(ActivityIndicator, {
    testID: "activity-indicator",
    color: theme?.colors?.textColor || DefaultTheme[mode].colors.primaryColor,
    size: "large"
  }));
};
const style = StyleSheet.create({
  container: {
    justifyContent: 'center',
    alignItems: 'center',
    flex: 1,
    minHeight: 100,
    width: '100%'
  }
});
export default LoadingWindow;
//# sourceMappingURL=loadingWindow.js.map